Package: ProcessCapabilityR
Type: Package
Title: Classical and Generalized Process Capability Indices
Version: 0.1.0
Authors@R: c(
    person("Shikhar", "Tyagi",
           email = "shikhar1093tyagi@gmail.com",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-1606-0844")),
    person("Sumit", "Kumar",
           email = "stats.sumitbhal@gmail.com",
           role = "aut"),
    person("Vrijesh", "Tripathi",
           email = "vrijesh.tripathi@uwi.edu",
           role = "aut")
    )
Maintainer: Shikhar Tyagi <shikhar1093tyagi@gmail.com>
Description: Computes classical process capability indices (Cp, Cpk, Cpu, Cpl,
    Cpm, Cpmk, Pp, Ppk, Ppu, Ppl, Z) and the generalized process capability
    index Cpy (Maiti, Saha & Nanda, 2010) <doi:10.1080/16843703.2010.11673233>
    for any continuous or discrete quality characteristic. Users supply the
    probability density function (PDF) and cumulative distribution function (CDF)
    of the characteristic, and the package returns point estimates, bootstrap
    confidence intervals (percentile and BCa), and sensitivity tables/plots
    across ranges of short-term standard deviation (sigma), long-term standard
    deviation (s), desired yield (p0), and significance levels. Classical indices
    are recoverable as special cases under the normal distribution. The package
    follows the theory and notation of Kane (1986) <doi:10.1080/00224065.1986.11978984>,
    Chan, Cheng & Spiring (1988) <doi:10.1080/00224065.1988.11979102>,
    Pearn, Kotz & Johnson (1992) <doi:10.1080/00224065.1992.11979403>,
    Kotz & Johnson (2002) <doi:10.1080/00224065.2002.11980119>,
    Montgomery (2020, ISBN:978-1-119-39930-8), Juran (1974, ISBN:978-0-07-033176-1),
    Harry & Schroeder (2000, ISBN:978-0-385-49437-2), and the AIAG SPC Reference
    Manual (2005, ISBN:978-1-60534-026-3).
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 3.5.0)
Imports: stats
Suggests: ggplot2 (>= 3.0.0), testthat (>= 3.0.0), knitr, rmarkdown
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-23 17:54:01 UTC; 30017827
Author: Shikhar Tyagi [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1606-0844>),
  Sumit Kumar [aut],
  Vrijesh Tripathi [aut]
Repository: CRAN
Date/Publication: 2026-08-03 18:00:24 UTC
