% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{validate_positive}
\alias{validate_positive}
\title{Validate that a value is positive}
\usage{
validate_positive(x, name)
}
\arguments{
\item{x}{Value to check}

\item{name}{Name of the parameter (for error message)}
}
\value{
Invisibly returns \code{NULL}. Called for side effects (input validation).
}
\description{
Validate that a value is positive
}
\keyword{internal}
