% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{require_param}
\alias{require_param}
\title{Require a parameter to be non-NULL}
\usage{
require_param(x, name, index)
}
\arguments{
\item{x}{Value to check}

\item{name}{Name of the parameter}

\item{index}{Name of the index requiring this parameter}
}
\value{
Invisibly returns \code{NULL}. Called for side effects (input validation).
}
\description{
Require a parameter to be non-NULL
}
\keyword{internal}
