% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{cpmk}
\alias{cpmk}
\title{Modified Taguchi Capability Index (Cpmk)}
\usage{
cpmk(LSL, USL, mu, sigma, target)
}
\arguments{
\item{LSL}{Lower specification limit.}

\item{USL}{Upper specification limit.}

\item{mu}{Short-term process mean.}

\item{sigma}{Short-term standard deviation.}

\item{target}{Target value \eqn{T}.}
}
\value{
Numeric value of \eqn{C_{pmk}}.
}
\description{
\eqn{C_{pmk} = \min\bigl((USL-\mu),\;(\mu-LSL)\bigr) /
  \bigl(3\sqrt{\sigma^2+(\mu-T)^2}\bigr)}.
}
\examples{
cpmk(LSL = 57, USL = 63, mu = 60, sigma = 1, target = 60)   # 1.0
}
\seealso{
\code{\link{pci}}
}
