% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{inverse_cdf_sample}
\alias{inverse_cdf_sample}
\title{Draw random samples from a pci_dist via inverse-CDF sampling}
\usage{
inverse_cdf_sample(dist, n)
}
\arguments{
\item{dist}{A \code{pci_dist} object.}

\item{n}{Number of samples to draw.}
}
\value{
Numeric vector of length \code{n}.
}
\description{
Generates samples by drawing U ~ Uniform(0,1) and inverting the CDF
using \code{\link[stats]{uniroot}}.
}
\keyword{internal}
