% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{ppu}
\alias{ppu}
\title{Upper Performance Index (Ppu)}
\usage{
ppu(USL, xbar, s)
}
\arguments{
\item{USL}{Upper specification limit.}

\item{xbar}{Long-term mean.}

\item{s}{Long-term standard deviation.}
}
\value{
Numeric value of \eqn{P_{pu}}.
}
\description{
\eqn{P_{pu} = (USL - \bar{x}) / (3s)}.
}
\examples{
ppu(USL = 63, xbar = 60, s = 1.5)   # 0.6667
}
\seealso{
\code{\link{pci}}
}
