% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{ppk}
\alias{ppk}
\title{Performance Capability Index (Ppk)}
\usage{
ppk(LSL, USL, xbar, s)
}
\arguments{
\item{LSL}{Lower specification limit.}

\item{USL}{Upper specification limit.}

\item{xbar}{Long-term (overall) mean.}

\item{s}{Long-term standard deviation.}
}
\value{
Numeric value of \eqn{P_{pk}}.
}
\description{
\eqn{P_{pk} = \min\bigl((USL-\bar{x})/(3s),\;(\bar{x}-LSL)/(3s)\bigr)}.
}
\examples{
ppk(LSL = 57, USL = 63, xbar = 60, s = 1.5)   # 0.6667
}
\seealso{
\code{\link{pci}}
}
