% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{validate_alpha}
\alias{validate_alpha}
\title{Validate significance level alpha}
\usage{
validate_alpha(alpha)
}
\arguments{
\item{alpha}{Significance level}
}
\value{
Invisibly returns \code{NULL}. Called for side effects (input validation).
}
\description{
Validate significance level alpha
}
\keyword{internal}
