% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{cp}
\alias{cp}
\title{Process Potential Index (Cp)}
\usage{
cp(LSL, USL, sigma)
}
\arguments{
\item{LSL}{Lower specification limit.}

\item{USL}{Upper specification limit.}

\item{sigma}{Short-term (within-subgroup) standard deviation.}
}
\value{
Numeric value of \eqn{C_p}.
}
\description{
\eqn{C_p = (USL - LSL) / (6\sigma)}.
}
\examples{
cp(LSL = 57, USL = 63, sigma = 1)   # 1.0
}
\seealso{
\code{\link{pci}}
}
