% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{compute_index_from_sample}
\alias{compute_index_from_sample}
\title{Compute a PCI from sample statistics}
\usage{
compute_index_from_sample(
  index,
  sample_data,
  LSL,
  USL,
  target,
  LDL,
  UDL,
  p0,
  dist
)
}
\value{
A numeric value of the calculated process capability index, or \code{NA_real_} on error/invalid input.
}
\description{
Compute a PCI from sample statistics
}
\keyword{internal}
