% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{cpl}
\alias{cpl}
\title{Lower Capability Index (Cpl)}
\usage{
cpl(LSL, mu, sigma)
}
\arguments{
\item{LSL}{Lower specification limit.}

\item{mu}{Short-term process mean.}

\item{sigma}{Short-term standard deviation.}
}
\value{
Numeric value of \eqn{C_{pl}}.
}
\description{
\eqn{C_{pl} = (\mu - LSL) / (3\sigma)}.
}
\examples{
cpl(LSL = 57, mu = 60, sigma = 1)   # 1.0
}
\seealso{
\code{\link{pci}}
}
