% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{validate_p0}
\alias{validate_p0}
\title{Validate desired yield p0}
\usage{
validate_p0(p0)
}
\arguments{
\item{p0}{Desired yield}
}
\value{
Invisibly returns \code{NULL}. Called for side effects (input validation).
}
\description{
Validate desired yield p0
}
\keyword{internal}
