% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{z_level}
\alias{z_level}
\title{Sigma Level (Z)}
\usage{
z_level(LSL, USL, mu, sigma)
}
\arguments{
\item{LSL}{Lower specification limit.}

\item{USL}{Upper specification limit.}

\item{mu}{Short-term process mean.}

\item{sigma}{Short-term standard deviation.}
}
\value{
Numeric value of \eqn{Z}.
}
\description{
\eqn{Z = \min\bigl((USL-\mu)/\sigma,\;(\mu-LSL)/\sigma\bigr)}.
}
\examples{
z_level(LSL = 57, USL = 63, mu = 60, sigma = 1)   # 3.0
}
\seealso{
\code{\link{pci}}
}
