% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pci_dist.R
\name{print.pci_dist}
\alias{print.pci_dist}
\title{Print method for pci_dist objects}
\usage{
\method{print}{pci_dist}(x, ...)
}
\arguments{
\item{x}{A \code{pci_dist} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
Invisibly returns the input \code{x} of class \code{"pci_dist"}.
  Called for side effect of printing distribution parameters and specification details to the console.
}
\description{
Print method for pci_dist objects
}
