% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{ppl}
\alias{ppl}
\title{Lower Performance Index (Ppl)}
\usage{
ppl(LSL, xbar, s)
}
\arguments{
\item{LSL}{Lower specification limit.}

\item{xbar}{Long-term mean.}

\item{s}{Long-term standard deviation.}
}
\value{
Numeric value of \eqn{P_{pl}}.
}
\description{
\eqn{P_{pl} = (\bar{x} - LSL) / (3s)}.
}
\examples{
ppl(LSL = 57, xbar = 60, s = 1.5)   # 0.6667
}
\seealso{
\code{\link{pci}}
}
