% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{validate_spec_limits}
\alias{validate_spec_limits}
\title{Validate specification limits}
\usage{
validate_spec_limits(LSL, USL)
}
\arguments{
\item{LSL}{Lower specification limit}

\item{USL}{Upper specification limit}
}
\value{
Invisibly returns \code{NULL}. Called for side effects (input validation).
}
\description{
Validate specification limits
}
\keyword{internal}
