% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{cpu}
\alias{cpu}
\title{Upper Capability Index (Cpu)}
\usage{
cpu(USL, mu, sigma)
}
\arguments{
\item{USL}{Upper specification limit.}

\item{mu}{Short-term process mean.}

\item{sigma}{Short-term standard deviation.}
}
\value{
Numeric value of \eqn{C_{pu}}.
}
\description{
\eqn{C_{pu} = (USL - \mu) / (3\sigma)}.
}
\examples{
cpu(USL = 63, mu = 60, sigma = 1)   # 1.0
}
\seealso{
\code{\link{pci}}
}
