% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{compute_desirable_limits}
\alias{compute_desirable_limits}
\title{Compute symmetric desirable limits for Cpy}
\usage{
compute_desirable_limits(dist, p0)
}
\arguments{
\item{dist}{A \code{pci_dist} object.}

\item{p0}{Desired yield (probability), in (0, 1].}
}
\value{
Named numeric vector \code{c(LDL = ..., UDL = ...)}.
}
\description{
Given a \code{pci_dist} and desired yield \code{p0}, computes
LDL and UDL symmetric about the median of the distribution such
that \code{F(UDL) - F(LDL) = p0}.
}
\keyword{internal}
