% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pci_ci.R
\name{print.pci_ci}
\alias{print.pci_ci}
\title{Print method for pci_ci objects}
\usage{
\method{print}{pci_ci}(x, ...)
}
\arguments{
\item{x}{A \code{pci_ci} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
Invisibly returns the input \code{x} of class \code{"pci_ci"}.
  Called for side effect of printing formatted confidence interval details to the console.
}
\description{
Print method for pci_ci objects
}
