% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience.R
\name{pp}
\alias{pp}
\title{Performance Index (Pp)}
\usage{
pp(LSL, USL, s)
}
\arguments{
\item{LSL}{Lower specification limit.}

\item{USL}{Upper specification limit.}

\item{s}{Long-term (overall) standard deviation.}
}
\value{
Numeric value of \eqn{P_p}.
}
\description{
\eqn{P_p = (USL - LSL) / (6s)}.
}
\examples{
pp(LSL = 57, USL = 63, s = 1.5)   # 0.6667
}
\seealso{
\code{\link{pci}}
}
